Received

Struct Received 

pub struct Received {
    pub id: u8,
    pub topic: String<256>,
    pub msg_length: u16,
    pub qos: Qos,
    pub mid: Option<u16>,
}

Fields

id: u8

Client ID. The only supported value is 0 - 1 client.

topic: String<256>

The topic the client wants to publish to.

msg_length: u16

Size of the message payload.

qos: Qos

The quality of service level to request for the subscription.

mid: Option<u16>

Id of the message to read. is generated by the broker.

A maximum of 100 messages are saved in the FIFO after +SQNSMQTTONMESSAGE is emitted. If the queue overflows, the URC +SQNSMQTTMEMORYFULL is sent and the oldest messages are lost.

A message with =0 doesn’t have a <mid›, as this type of message is overwritten every time a new message arrives. No value is to be given to read a message with =0.