pub struct Received {
pub id: u8,
pub topic: String<256>,
pub msg_length: u16,
pub qos: Qos,
pub mid: Option<u16>,
}Fields
id: u8Client ID. The only supported value is 0 - 1 client.
topic: String<256>The topic the client wants to publish to.
msg_length: u16Size of the message payload.
qos: QosThe quality of service level to request for the subscription.
mid: Option<u16>Id of the message to read.
A maximum of 100 messages are saved in the FIFO after +SQNSMQTTONMESSAGE is emitted. If the queue overflows, the URC +SQNSMQTTMEMORYFULL is sent and the oldest messages are lost.
A message with